#
# spec file for package python-xmlsec
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-xmlsec
Version:        1.3.14
Release:        1.1
Summary:        Python bindings for the XML Security Library
License:        MIT
URL:            https://github.com/mehcode/python-xmlsec
Source:         https://files.pythonhosted.org/packages/source/x/xmlsec/xmlsec-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module lxml >= 3.8.0}
BuildRequires:  %{python_module lxml-devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pkgconfig}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module toml}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
# we need at least one backend
BuildRequires:  libxmlsec1-openssl1
BuildRequires:  pkgconfig(xmlsec1)
# we need at least one xmlsec backend on runtime
Recommends:     libxmlsec1-openssl1
Requires:       python-lxml >= 3.8.0
%python_subpackages

%description
Python bindings for the XML Security Library

%prep
%autosetup -p1 -n xmlsec-%{version}

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
# gh#xmlsec/python-xmlsec#244
donttest="test_sign_case5"

# Run tests with -n 1 to avoid race condition in tests
# gh#xmlsec/python-xmlsec#210
%pytest_arch -n 1 -k "not (${donttest})" tests/

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitearch}/xmlsec
%{python_sitearch}/xmlsec-%{version}*-info
%{python_sitearch}/xmlsec*.so

%changelog
* Mon Jun 10 2024 Dirk Müller <dmueller@suse.com>
- update to 1.3.14:
  * XMLSec 1.3.x compliance
  * Make DES/3DES/KW-3DES support conditional on DES availability
    in XMLSec
  * PKCS11 support
  * Improved libxml2 version check
  * Several test improvements
* Thu Nov  2 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Mon Dec 19 2022 Daniel Garcia <daniel.garcia@suse.com>
- Run tests with -n1 to avoid race condition in tests
  gh#xmlsec/python-xmlsec#210
* Tue Oct 18 2022 Markéta Machová <mmachova@suse.com>
- Update to 1.13.13
  * Add CI for Python 3.10, manylinux2 SOABI, musllinux1 SOABI and OpenSUSE Tumbleweed
  * Introduce linting with pre-commit
  * Rewrite PEP 484 stubs
  * xmlsec workaround for gh##84
  * Resolve key loading issue on big-endian systems.
  * Fix building wheel when using PYXMLSEC_STATIC_DEPS=true
  * setup.py: Fix typo in PYXMLSEC_LIBXSLT_VERSION
  * Switch on modern headers lxml
  * use build to build wheels
  * remove pkgconfig as it's only a build-system requirement
  * exclude lxml 4.7 because the wheels are missing the lxml includes
- Drop merged avoid_lxml_tests_failing.patch
- Normalize the tests call
* Wed May 11 2022 Matej Cepl <mcepl@suse.com>
- Update to 1.3.12:
  - Added support for registering custom xmlsec IO callbacks
  - Added support for building without MD5 transforms
  - Added support for PEP 539 for Python 3.7 and newer
  - Using lxml-stubs package instead of custom LXML stubs
- Add avoid_lxml_tests_failing.patch (help working
  around the lxml issue lp#1880251 and lp#1887848, from
  gh#mehcode/python-xmlsec#84).
- Switch off building on Python 3.10 and %%ix86
  (gh#mehcode/python-xmlsec#204).
* Thu Jun 10 2021 Matej Cepl <mcepl@suse.com>
- Upgrade to 1.3.11:
  - Removed Python 2 compatibility code.
  - Fixed bug with unused custom error callback.
  - Added support for building with XMLSEC_NO_XSLT macro.
  - Switched docs theme to furo.
  - Fixed libxmlsec1 version checks
  - More tests added to increase test coverage
  - Various small fixes for segfaults found
  - Added xmlsec.base64_default_line_size() function to set the
    default maximum columns size for base64 encoding
  - Added AES-GCM transform constants
  - Added Python 3.9 support
* Tue Jun  2 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.3.8:
  * No upstream changelog.
- Drop reproducible.patch, included upstream.
- Switch to PyPI tarball due to use of setuptools_scm.
- Update BuildRequires.
* Mon Jun 24 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to sort dir entries (boo#1041090)
* Fri Dec  7 2018 Tomáš Chvátal <tchvatal@suse.com>
- Version update to 1.3.6:
  * Various installation issue fxes
- Make sure the tests are really run and skipped for now
- Make sure to pick up at least one xmlsec backend
* Wed Nov 21 2018 Tomáš Chvátal <tchvatal@suse.com>
- Format with spec-cleaner
* Mon Nov 19 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 1.3.3
